{
    'name': 'Website Theme Install',
    'summary': 'Select a theme for your website',
    'description': "",
    'category': 'Hidden',
    'version': '1.0',
    'data': [
        'views/assets.xml',
        'views/views.xml',
        'views/res_config_settings_views.xml',
        'security/ir.model.access.csv',
    ],
    'depends': ['website'],
    'auto_install': True,
}
